<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv_SE">
<context>
    <name>QtLocationQML</name>
    <message>
        <source>Plugin property is not set.</source>
        <translation>Insticksmodulegenskap är inte inställd.</translation>
    </message>
    <message>
        <source>Plugin Error (%1): %2</source>
        <translation>Insticksmodulfel (%1): %2</translation>
    </message>
    <message>
        <source>Plugin Error (%1): Could not instantiate provider</source>
        <translation>Insticksmodulfel (%1): Kunde inte instansiera leverantör</translation>
    </message>
    <message>
        <source>Plugin is not valid</source>
        <translation>Insticksmodulen är inte giltig</translation>
    </message>
    <message>
        <source>Unable to initialize categories</source>
        <translation>Kunde inte initiera kategorier</translation>
    </message>
    <message>
        <source>Unable to create request</source>
        <translation>Kunde inte skapa begäran</translation>
    </message>
    <message>
        <source>Index &apos;%1&apos; out of range</source>
        <translation>Indexet &apos;%1&apos; är utanför intervallet</translation>
    </message>
    <message>
        <source>Qt Location requires apiKey parameter.
Please register at https://developer.here.com/ to get your personal application credentials.</source>
        <translation>Qt Location kräver apiKey-parameter.
Registrera dig på https://developer.here.com/ för att få din personliga programinloggning.</translation>
    </message>
    <message>
        <source>Saving places is not supported.</source>
        <translation>Sparning av platser stöds inte.</translation>
    </message>
    <message>
        <source>Removing places is not supported.</source>
        <translation>Borttagning av platser stöds inte.</translation>
    </message>
    <message>
        <source>Saving categories is not supported.</source>
        <translation>Sparning av kategorier stöds inte.</translation>
    </message>
    <message>
        <source>Removing categories is not supported.</source>
        <translation>Borttagning av kategorier stöds inte.</translation>
    </message>
    <message>
        <source>Error parsing response.</source>
        <translation>Fel vid tolkning av svar.</translation>
    </message>
    <message>
        <source>Network error.</source>
        <translation>Nätverksfel.</translation>
    </message>
    <message>
        <source>Request was canceled.</source>
        <translation>Begäran avbröts.</translation>
    </message>
    <message>
        <source>The response from the service was not in a recognizable format.</source>
        <translation>Svaret från tjänsten var inte i ett känt format.</translation>
    </message>
</context>
<context>
    <name>QDeclarativeGeocodeModel</name>
    <message>
        <source>Cannot geocode, plugin not set.</source>
        <translation>Kan inte geocode, insticksmodul inte inställd.</translation>
    </message>
    <message>
        <source>Cannot geocode, geocode manager not set.</source>
        <translation>Kan inte geocode, geocode-hanterare inte inställd.</translation>
    </message>
    <message>
        <source>Cannot geocode, valid query not set.</source>
        <translation>Kan inte geocode, giltig frågesats inte inställd.</translation>
    </message>
    <message>
        <source>Plugin does not support (reverse) geocoding.</source>
        <translation>Insticksmodulen har inte stöd för (omvänd) geocoding.</translation>
    </message>
</context>
<context>
    <name>QDeclarativeGeoRouteModel</name>
    <message>
        <source>Plugin does not support routing.</source>
        <translation>Insticksmodulen har inte stöd för rutter.</translation>
    </message>
    <message>
        <source>Cannot route, plugin not set.</source>
        <translation>Kan inte lägga rutt, instickmodul inte inställd.</translation>
    </message>
    <message>
        <source>Cannot route, route manager not set.</source>
        <translation>Kan inte lägga rutt, rutthanterare inte inställd.</translation>
    </message>
    <message>
        <source>Cannot route, valid query not set.</source>
        <translation>Kan inte lägga rutt, giltig frågesats inte inställd.</translation>
    </message>
    <message>
        <source>Not enough waypoints for routing.</source>
        <translation>Inte tillräckliga vägpunkter för rutt.</translation>
    </message>
</context>
<context>
    <name>QGeoRouteParserOsrmV5</name>
    <message>
        <source>North</source>
        <extracomment>Translations exist at https://github.com/Project-OSRM/osrm-text-instructions. Always used in &quot;Head %1 [onto &lt;street name&gt;]&quot;</extracomment>
        <translation>Norr</translation>
    </message>
    <message>
        <source>East</source>
        <translation>Öst</translation>
    </message>
    <message>
        <source>South</source>
        <translation>Syd</translation>
    </message>
    <message>
        <source>West</source>
        <translation>Väster</translation>
    </message>
    <message>
        <source>first</source>
        <comment>roundabout exit</comment>
        <extracomment>always used in &quot; and take the %1 exit [onto &lt;street name&gt;]&quot;</extracomment>
        <translation>första</translation>
    </message>
    <message>
        <source>second</source>
        <comment>roundabout exit</comment>
        <translation>andra</translation>
    </message>
    <message>
        <source>third</source>
        <comment>roundabout exit</comment>
        <translation>tredje</translation>
    </message>
    <message>
        <source>fourth</source>
        <comment>roundabout exit</comment>
        <translation>fjärde</translation>
    </message>
    <message>
        <source>fifth</source>
        <comment>roundabout exit</comment>
        <translation>femte</translation>
    </message>
    <message>
        <source>sixth</source>
        <comment>roundabout exit</comment>
        <translation>sjätte</translation>
    </message>
    <message>
        <source>seventh</source>
        <comment>roundabout exit</comment>
        <translation>sjunde</translation>
    </message>
    <message>
        <source>eighth</source>
        <comment>roundabout exit</comment>
        <translation>åttonde</translation>
    </message>
    <message>
        <source>ninth</source>
        <comment>roundabout exit</comment>
        <translation>nionde</translation>
    </message>
    <message>
        <source>tenth</source>
        <comment>roundabout exit</comment>
        <translation>tionde</translation>
    </message>
    <message>
        <source>eleventh</source>
        <comment>roundabout exit</comment>
        <translation>elfte</translation>
    </message>
    <message>
        <source>twelfth</source>
        <comment>roundabout exit</comment>
        <translation>tolfte</translation>
    </message>
    <message>
        <source>thirteenth</source>
        <comment>roundabout exit</comment>
        <translation>trettonde</translation>
    </message>
    <message>
        <source>fourteenth</source>
        <comment>roundabout exit</comment>
        <translation>fjortonde</translation>
    </message>
    <message>
        <source>fifteenth</source>
        <comment>roundabout exit</comment>
        <translation>femtonde</translation>
    </message>
    <message>
        <source>sixteenth</source>
        <comment>roundabout exit</comment>
        <translation>sextonde</translation>
    </message>
    <message>
        <source>seventeenth</source>
        <comment>roundabout exit</comment>
        <translation>sjuttonde</translation>
    </message>
    <message>
        <source>eighteenth</source>
        <comment>roundabout exit</comment>
        <translation>artonde</translation>
    </message>
    <message>
        <source>nineteenth</source>
        <comment>roundabout exit</comment>
        <translation>nittonde</translation>
    </message>
    <message>
        <source>twentieth</source>
        <comment>roundabout exit</comment>
        <translation>tjugonde</translation>
    </message>
    <message>
        <source> and take the %1 exit</source>
        <extracomment>Always appended to one of the following strings: - &quot;Enter the roundabout&quot; - &quot;Enter the rotary&quot; - &quot;Enter the rotary &lt;rotaryname&gt;&quot;</extracomment>
        <translation> och ta %1 avfarten</translation>
    </message>
    <message>
        <source> and take the %1 exit onto %2</source>
        <translation> och ta %1 avfarten in på %2</translation>
    </message>
    <message>
        <source>You have arrived at your destination, straight ahead</source>
        <translation>Du har kommit fram till ditt mål, rakt fram</translation>
    </message>
    <message>
        <source>You have arrived at your destination, on the left</source>
        <translation>Du har kommit fram till ditt mål, till vänster</translation>
    </message>
    <message>
        <source>You have arrived at your destination, on the right</source>
        <translation>Du har kommit fram till ditt mål, till höger</translation>
    </message>
    <message>
        <source>You have arrived at your destination</source>
        <translation>Du har kommit fram till ditt mål</translation>
    </message>
    <message>
        <source>Continue straight</source>
        <translation>Fortsätt rakt framåt</translation>
    </message>
    <message>
        <source>Continue straight on %1</source>
        <translation>Fortsätt rakt fram på %1</translation>
    </message>
    <message>
        <source>Continue left</source>
        <translation>Fortsätt till vänster</translation>
    </message>
    <message>
        <source>Continue left onto %1</source>
        <translation>Fortsätt till vänster in på %1</translation>
    </message>
    <message>
        <source>Continue slightly left</source>
        <translation>Fortsätt svagt till vänster</translation>
    </message>
    <message>
        <source>Continue slightly left on %1</source>
        <translation>Fortsätt svagt till vänster in på %1</translation>
    </message>
    <message>
        <source>Continue right</source>
        <translation>Fortsätt till höger</translation>
    </message>
    <message>
        <source>Continue right onto %1</source>
        <translation>Fortsätt till höger in på %1</translation>
    </message>
    <message>
        <source>Continue slightly right</source>
        <translation>Fortsätt svagt till höger</translation>
    </message>
    <message>
        <source>Continue slightly right on %1</source>
        <translation>Fortsätt svagt till höger in på %1</translation>
    </message>
    <message>
        <source>Make a U-turn</source>
        <translation>Gör en u-sväng</translation>
    </message>
    <message>
        <source>Make a U-turn onto %1</source>
        <translation>Gör en u-sväng in på %1</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>Fortsätt</translation>
    </message>
    <message>
        <source>Continue on %1</source>
        <translation>Fortsätt på %1</translation>
    </message>
    <message>
        <source>Head %1</source>
        <extracomment>%1 is &quot;North&quot;, &quot;South&quot;, &quot;East&quot; or &quot;West&quot;</extracomment>
        <translation></translation>
    </message>
    <message>
        <source>Head %1 onto %2</source>
        <translation>Rakt fram %1 in på %2</translation>
    </message>
    <message>
        <source>Depart</source>
        <translation>Avresa</translation>
    </message>
    <message>
        <source>Depart onto %1</source>
        <translation>Avres in på %1</translation>
    </message>
    <message>
        <source>At the end of the road, turn left</source>
        <translation>Vid slutet av vägen, sväng vänster</translation>
    </message>
    <message>
        <source>At the end of the road, turn left onto %1</source>
        <translation>Vid slutet av vägen, sväng vänster in på %1</translation>
    </message>
    <message>
        <source>At the end of the road, turn right</source>
        <translation>Vid slutet av vägen, sväng höger</translation>
    </message>
    <message>
        <source>At the end of the road, turn right onto %1</source>
        <translation>Vid slutet av vägen, sväng höger in på %1</translation>
    </message>
    <message>
        <source>At the end of the road, make a U-turn</source>
        <translation>Vid slutet av vägen, gör en u-sväng</translation>
    </message>
    <message>
        <source>At the end of the road, make a U-turn onto %1</source>
        <translation>Vid slutet av vägen, gör en u-sväng in på %1</translation>
    </message>
    <message>
        <source>At the end of the road, continue straight</source>
        <translation>Vid slutet av vägen, fortsätt rakt fram</translation>
    </message>
    <message>
        <source>At the end of the road, continue straight onto %1</source>
        <translation>Vid slutet av vägen, fortsätt rakt fram in på %1</translation>
    </message>
    <message>
        <source>At the end of the road, continue</source>
        <translation>Vid slutet av vägen, fortsätt</translation>
    </message>
    <message>
        <source>At the end of the road, continue onto %1</source>
        <translation>Vid slutet av vägen, fortsätt in på %1</translation>
    </message>
    <message>
        <source>Take the ferry</source>
        <translation>Ta färjan</translation>
    </message>
    <message>
        <source>At the fork, take a sharp left</source>
        <translation>Vid delningen, gör en skarp vänstersväng</translation>
    </message>
    <message>
        <source>At the fork, take a sharp left onto %1</source>
        <translation>Vid delningen, gör en skarp vänstersväng in på %1</translation>
    </message>
    <message>
        <source>At the fork, turn left</source>
        <translation>Vid delningen, sväng vänster</translation>
    </message>
    <message>
        <source>At the fork, turn left onto %1</source>
        <translation>Vid delningen, sväng vänster in på %1</translation>
    </message>
    <message>
        <source>At the fork, keep left</source>
        <translation>Vid delningen, håll dig till vänster</translation>
    </message>
    <message>
        <source>At the fork, keep left onto %1</source>
        <translation>Vid delningen, håll vänster in på %1</translation>
    </message>
    <message>
        <source>At the fork, take a sharp right</source>
        <translation>Vid delningen, gör en skarp högersväng</translation>
    </message>
    <message>
        <source>At the fork, take a sharp right onto %1</source>
        <translation>Vid delningen, gör en skarp högersväng in på %1</translation>
    </message>
    <message>
        <source>At the fork, turn right</source>
        <translation>Vid delningen, sväng höger</translation>
    </message>
    <message>
        <source>At the fork, turn right onto %1</source>
        <translation>Vid delningen, sväng höger in på %1</translation>
    </message>
    <message>
        <source>At the fork, keep right</source>
        <translation>Vid delningen, håll dig till höger</translation>
    </message>
    <message>
        <source>At the fork, keep right onto %1</source>
        <translation>Vid delningen, håll dig till höger in på %1</translation>
    </message>
    <message>
        <source>At the fork, continue straight ahead</source>
        <translation>Vid delningen, fortsätt rakt fram</translation>
    </message>
    <message>
        <source>At the fork, continue straight ahead onto %1</source>
        <translation>Vid delningen, fortsätt rakt fram in på %1</translation>
    </message>
    <message>
        <source>At the fork, continue</source>
        <translation>Vid delningen, fortsätt</translation>
    </message>
    <message>
        <source>At the fork, continue onto %1</source>
        <translation>Vid delningen, fortsätt in på %1</translation>
    </message>
    <message>
        <source>Merge sharply left</source>
        <translation>Sammanslå skarpt åt vänster</translation>
    </message>
    <message>
        <source>Merge sharply left onto %1</source>
        <translation>Sammanslå skarpt åt vänster in på %1</translation>
    </message>
    <message>
        <source>Merge left</source>
        <translation>Sammanslå åt vänster</translation>
    </message>
    <message>
        <source>Merge left onto %1</source>
        <translation>Sammanslå åt vänster in på %1</translation>
    </message>
    <message>
        <source>Merge slightly left</source>
        <translation>Sammanslå svagt åt vänster</translation>
    </message>
    <message>
        <source>Merge slightly left on %1</source>
        <translation>Sammanslå svagt åt vänster in på %1</translation>
    </message>
    <message>
        <source>Merge sharply right</source>
        <translation>Sammanslå skarpt åt höger</translation>
    </message>
    <message>
        <source>Merge sharply right onto %1</source>
        <translation>Sammanslå skarpt åt höger in på %1</translation>
    </message>
    <message>
        <source>Merge right</source>
        <translation>Sammanslå åt höger</translation>
    </message>
    <message>
        <source>Merge right onto %1</source>
        <translation>Sammanslå åt höger in på %1</translation>
    </message>
    <message>
        <source>Merge slightly right</source>
        <translation>Sammanslå svagt åt höger</translation>
    </message>
    <message>
        <source>Merge slightly right on %1</source>
        <translation>Sammanslå svagt åt höger in på %1</translation>
    </message>
    <message>
        <source>Merge straight</source>
        <translation>Sammanslå rakt fram</translation>
    </message>
    <message>
        <source>Merge straight on %1</source>
        <translation>Sammanslå rakt fram på %1</translation>
    </message>
    <message>
        <source>Merge</source>
        <translation>Sammanslå</translation>
    </message>
    <message>
        <source>Merge onto %1</source>
        <translation>Sammanslå in på %1</translation>
    </message>
    <message>
        <source>Take a sharp left</source>
        <translation>Gör en skarp vänstersväng</translation>
    </message>
    <message>
        <source>Take a sharp left onto %1</source>
        <translation>Gör en skarp vänstersväng in på %1</translation>
    </message>
    <message>
        <source>Turn left</source>
        <translation>Sväng vänster</translation>
    </message>
    <message>
        <source>Turn left onto %1</source>
        <translation>Sväng vänster in på %1</translation>
    </message>
    <message>
        <source>Continue slightly left onto %1</source>
        <translation>Fortsätt svagt till vänster in på %1</translation>
    </message>
    <message>
        <source>Take a sharp right</source>
        <translation>Gör en skarp högersväng</translation>
    </message>
    <message>
        <source>Take a sharp right onto %1</source>
        <translation>Gör en skarp högersväng in på %1</translation>
    </message>
    <message>
        <source>Turn right</source>
        <translation>Sväng höger</translation>
    </message>
    <message>
        <source>Turn right onto %1</source>
        <translation>Sväng höger in på %1</translation>
    </message>
    <message>
        <source>Continue slightly right onto %1</source>
        <translation>Fortsätt svagt till höger in på %1</translation>
    </message>
    <message>
        <source>Continue straight onto %1</source>
        <translation>Fortsätt rakt fram in på %1</translation>
    </message>
    <message>
        <source>Continue onto %1</source>
        <translation>Fortsätt in på %1</translation>
    </message>
    <message>
        <source>Continue on the left</source>
        <translation>Fortsätt till vänster</translation>
    </message>
    <message>
        <source>Continue on the left on %1</source>
        <translation>Fortsätt till vänster in på %1</translation>
    </message>
    <message>
        <source>Continue on the right</source>
        <translation>Fortsätt till höger</translation>
    </message>
    <message>
        <source>Continue on the right on %1</source>
        <translation>Fortsätt till höger in på %1</translation>
    </message>
    <message>
        <source>Take the ramp on the left</source>
        <translation>Ta rampen till vänster</translation>
    </message>
    <message>
        <source>Take the ramp on the left onto %1</source>
        <translation>Ta rampen till vänster in på %1</translation>
    </message>
    <message>
        <source>Take the ramp on the right</source>
        <translation>Ta rampen till höger</translation>
    </message>
    <message>
        <source>Take the ramp on the right onto %1</source>
        <translation>Ta rampen till höger in på %1</translation>
    </message>
    <message>
        <source>Take the ramp</source>
        <translation>Ta rampen</translation>
    </message>
    <message>
        <source>Take the ramp onto %1</source>
        <translation>Ta rampen in på %1</translation>
    </message>
    <message>
        <source>Get off the bike and push</source>
        <translation>Hoppa av cykeln och gå</translation>
    </message>
    <message>
        <source>Get off the bike and push onto %1</source>
        <translation>Hoppa av cykeln och gå in på %1</translation>
    </message>
    <message>
        <source>Enter the rotary</source>
        <extracomment>This string will be prepended to &quot; and take the &lt;nth&gt; exit [onto &lt;streetname&gt;]</extracomment>
        <translation>Åk in i rondellen</translation>
    </message>
    <message>
        <source>Enter the roundabout</source>
        <extracomment>This string will be prepended to &quot; and take the &lt;nth&gt; exit [onto &lt;streetname&gt;]</extracomment>
        <translation>In i rondellen</translation>
    </message>
    <message>
        <source>At the roundabout, continue straight</source>
        <translation>I rondellen, fortsätt rakt fram</translation>
    </message>
    <message>
        <source>At the roundabout, continue straight on %1</source>
        <translation>Vid rondellen, fortsätt rakt fram in på %1</translation>
    </message>
    <message>
        <source>At the roundabout, turn left</source>
        <translation>Vid rondellen, sväng vänster</translation>
    </message>
    <message>
        <source>At the roundabout, turn left onto %1</source>
        <translation>Vid rondellen, sväng vänster in på %1</translation>
    </message>
    <message>
        <source>At the roundabout, turn right</source>
        <translation>Vid rondellen, sväng höger</translation>
    </message>
    <message>
        <source>At the roundabout, turn right onto %1</source>
        <translation>Vid rondellen, sväng höger in på %1</translation>
    </message>
    <message>
        <source>At the roundabout, turn around</source>
        <translation>Vid rondellen, sväng runt</translation>
    </message>
    <message>
        <source>At the roundabout, turn around onto %1</source>
        <translation>Vid rondellen, sväng runt in på %1</translation>
    </message>
    <message>
        <source>At the roundabout, continue</source>
        <translation>Vid rondellen, fortsätt</translation>
    </message>
    <message>
        <source>At the roundabout, continue onto %1</source>
        <translation>Vid rondellen, fortsätt in på %1</translation>
    </message>
    <message>
        <source>Take the train</source>
        <translation>Ta tåget</translation>
    </message>
    <message>
        <source>Take the train [%1]</source>
        <translation>Ta tåget [%1]</translation>
    </message>
    <message>
        <source>Go straight</source>
        <translation>Gå rakt fram</translation>
    </message>
    <message>
        <source>Go straight onto %1</source>
        <translation>Gå rakt fram in på %1</translation>
    </message>
    <message>
        <source>Turn slightly left</source>
        <translation>Sväng svagt till vänster</translation>
    </message>
    <message>
        <source>Turn slightly left onto %1</source>
        <translation>Sväng svagt till vänster in på %1</translation>
    </message>
    <message>
        <source>Turn slightly right</source>
        <translation>Sväng svagt till höger</translation>
    </message>
    <message>
        <source>Turn slightly right onto %1</source>
        <translation>Sväng svagt till höger in på %1</translation>
    </message>
    <message>
        <source>Turn</source>
        <translation>Sväng</translation>
    </message>
    <message>
        <source>Turn onto %1</source>
        <translation>Sväng in på %1</translation>
    </message>
    <message>
        <source> and continue straight</source>
        <extracomment>This string will be prepended with lane instructions. E.g., &quot;Use the left or the right lane and continue straight&quot;</extracomment>
        <translation> och fortsätt rakt fram</translation>
    </message>
    <message>
        <source> and continue straight onto %1</source>
        <translation> och fortsätt rakt fram in på %1</translation>
    </message>
    <message>
        <source> and make a sharp left</source>
        <translation> och gör en skarp vänstersväng</translation>
    </message>
    <message>
        <source> and make a sharp left onto %1</source>
        <translation> och gör en skarp vänstersväng in på %1</translation>
    </message>
    <message>
        <source> and turn left</source>
        <translation> och sväng vänster</translation>
    </message>
    <message>
        <source> and turn left onto %1</source>
        <translation> och sväng vänster in på %1</translation>
    </message>
    <message>
        <source> and make a slight left</source>
        <translation> och gör en svag vänstersväng</translation>
    </message>
    <message>
        <source> and make a slight left onto %1</source>
        <translation> och gör en svag vänstersväng in på %1</translation>
    </message>
    <message>
        <source> and make a sharp right</source>
        <translation> och gör en skarp högersväng</translation>
    </message>
    <message>
        <source> and make a sharp right onto %1</source>
        <translation> och gör en skarp högersväng in på %1</translation>
    </message>
    <message>
        <source> and turn right</source>
        <translation> och sväng höger</translation>
    </message>
    <message>
        <source> and turn right onto %1</source>
        <translation> och sväng höger in på %1</translation>
    </message>
    <message>
        <source> and make a slight right</source>
        <translation> och gör en svag högersväng</translation>
    </message>
    <message>
        <source> and make a slight right onto %1</source>
        <translation> och gör en svag högersväng in på %1</translation>
    </message>
    <message>
        <source> and make a U-turn</source>
        <translation> och gör en u-sväng</translation>
    </message>
    <message>
        <source> and make a U-turn onto %1</source>
        <translation> och gör en u-sväng in på %1</translation>
    </message>
</context>
<context>
    <name>QDeclarativeGeoMap</name>
    <message>
        <source>No Map</source>
        <translation>Ingen karta</translation>
    </message>
    <message>
        <source>Plugin does not support mapping.</source>
        <translation>Insticksmodulen har inte stöd för mappning.</translation>
    </message>
</context>
<context>
    <name>GeoServiceProviderFactoryEsri</name>
    <message>
        <source>Esri plugin requires a &apos;esri.token&apos; parameter.
Please visit https://developers.arcgis.com/authentication/accessing-arcgis-online-services/</source>
        <translation>Insticksmodulen Esri kräver en &apos;esri.token&apos;-parameter.
Besök https://developers.arcgis.com/authentication/accessing-arcgis-online-services/</translation>
    </message>
</context>
<context>
    <name>PlaceSearchReplyEsri</name>
    <message>
        <source>Response parse error</source>
        <translation>Tolkningsfel av svaret</translation>
    </message>
</context>
<context>
    <name>QGeoMappingManagerEngineItemsOverlay</name>
    <message>
        <source>Empty Map</source>
        <translation>Tom karta</translation>
    </message>
</context>
<context>
    <name>QGeoCodeReplyMapbox</name>
    <message>
        <source>Response parse error</source>
        <translation>Tolkningsfel av svaret</translation>
    </message>
</context>
<context>
    <name>QGeoServiceProviderFactoryMapbox</name>
    <message>
        <source>Mapbox plugin requires a &apos;mapbox.access_token&apos; parameter.
Please visit https://www.mapbox.com</source>
        <translation>Insticksmodulen Mapbox kräver en &apos;mapbox.access_token&apos;-parameter.
Besök https://www.mapbox.com</translation>
    </message>
</context>
<context>
    <name>QGeoTiledMappingManagerEngineMapbox</name>
    <message>
        <source>Street</source>
        <extracomment>Noun describing map type &apos;Street map&apos;</extracomment>
        <translation>Gator</translation>
    </message>
    <message>
        <source>Light</source>
        <extracomment>Noun describing type of a map using light colors (weak contrast)</extracomment>
        <translation>Ljus</translation>
    </message>
    <message>
        <source>Dark</source>
        <extracomment>Noun describing type of a map using dark colors</extracomment>
        <translation>Mörk</translation>
    </message>
    <message>
        <source>Satellite</source>
        <extracomment>Noun describing type of a map created by satellite</extracomment>
        <translation>Satellit</translation>
    </message>
    <message>
        <source>Streets Satellite</source>
        <extracomment>Noun describing type of a street map created by satellite</extracomment>
        <translation>Gator enligt satelit</translation>
    </message>
    <message>
        <source>Wheatpaste</source>
        <extracomment>Noun describing type of a map using wheat paste colors</extracomment>
        <translation>Bleka färger</translation>
    </message>
    <message>
        <source>Streets Basic</source>
        <extracomment>Noun describing type of a basic street map</extracomment>
        <translation>Grundläggande gator</translation>
    </message>
    <message>
        <source>Comic</source>
        <extracomment>Noun describing type of a map using cartoon-style fonts</extracomment>
        <translation>Tecknad</translation>
    </message>
    <message>
        <source>Outdoors</source>
        <extracomment>Noun describing type of a map for outdoor activities</extracomment>
        <translation>Utomhus</translation>
    </message>
    <message>
        <source>Run Bike Hike</source>
        <extracomment>Noun describing type of a map for sports</extracomment>
        <translation>Kör cykla gå</translation>
    </message>
    <message>
        <source>Pencil</source>
        <extracomment>Noun describing type of a map drawn by pencil</extracomment>
        <translation>Blyerts</translation>
    </message>
    <message>
        <source>Pirates</source>
        <extracomment>Noun describing type of a treasure map with pirate boat watermark</extracomment>
        <translation>Pirater</translation>
    </message>
    <message>
        <source>Emerald</source>
        <extracomment>Noun describing type of a map using emerald colors</extracomment>
        <translation>Smaragd</translation>
    </message>
    <message>
        <source>High Contrast</source>
        <extracomment>Noun describing type of a map with high contrast</extracomment>
        <translation>Hög kontrast</translation>
    </message>
</context>
<context>
    <name>QPlaceSearchReplyMapbox</name>
    <message>
        <source>Response parse error</source>
        <translation>Tolkningsfel av svaret</translation>
    </message>
</context>
<context>
    <name>QPlaceSearchSuggestionReplyMapbox</name>
    <message>
        <source>Response parse error</source>
        <translation>Tolkningsfel av svaret</translation>
    </message>
</context>
<context>
    <name>QGeoMapMapboxGL</name>
    <message>
        <source>Development access token, do not use in production.</source>
        <translation>Accesstoken för utveckling, använd inte i produktion.</translation>
    </message>
</context>
<context>
    <name>QGeoMappingManagerEngineMapboxGL</name>
    <message>
        <source>China Streets</source>
        <translation>Kinagator</translation>
    </message>
    <message>
        <source>China Light</source>
        <translation>Kina ljus</translation>
    </message>
    <message>
        <source>China Dark</source>
        <translation>Kina mörk</translation>
    </message>
    <message>
        <source>Streets</source>
        <translation>Gator</translation>
    </message>
    <message>
        <source>Basic</source>
        <translation>Grundläggande</translation>
    </message>
    <message>
        <source>Bright</source>
        <translation>Starkt ljus</translation>
    </message>
    <message>
        <source>Outdoors</source>
        <translation>Utomhus</translation>
    </message>
    <message>
        <source>Satellite</source>
        <translation>Satellit</translation>
    </message>
    <message>
        <source>Satellite Streets</source>
        <translation>Satellitgator</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Ljus</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Mörk</translation>
    </message>
    <message>
        <source>Navigation Preview Day</source>
        <translation>Navigeringsförhandsvisning dag</translation>
    </message>
    <message>
        <source>Navigation Preview Night</source>
        <translation>Navigeringsförhandsvisning natt</translation>
    </message>
    <message>
        <source>Navigation Guidance Day</source>
        <translation>Navigeringsguidning dag</translation>
    </message>
    <message>
        <source>Navigation Guidance Night</source>
        <translation>Navigeringsguidning natt</translation>
    </message>
    <message>
        <source>User provided style</source>
        <translation>Användartillhandahållen stil</translation>
    </message>
</context>
<context>
    <name>QGeoTiledMappingManagerEngineNokia</name>
    <message>
        <source>Street Map</source>
        <translation>Gatukarta</translation>
    </message>
    <message>
        <source>Normal map view in daylight mode</source>
        <translation>Normal kartvy i dagsljusläge</translation>
    </message>
    <message>
        <source>Satellite Map</source>
        <translation>Satellitkarta</translation>
    </message>
    <message>
        <source>Satellite map view in daylight mode</source>
        <translation>Satellitkartvy i dagsljusläge</translation>
    </message>
    <message>
        <source>Terrain Map</source>
        <translation>Terrängkarta</translation>
    </message>
    <message>
        <source>Terrain map view in daylight mode</source>
        <translation>Terrängkartvy i dagsljusläge</translation>
    </message>
    <message>
        <source>Hybrid Map</source>
        <translation>Hybridkarta</translation>
    </message>
    <message>
        <source>Satellite map view with streets in daylight mode</source>
        <translation>Satellitkartvy med gator i dagsljusläge</translation>
    </message>
    <message>
        <source>Transit Map</source>
        <translation>Pendlarkarta</translation>
    </message>
    <message>
        <source>Color-reduced map view with public transport scheme in daylight mode</source>
        <translation>Färgreducerad kartvy med kollektivtrafik i dagsljusläge</translation>
    </message>
    <message>
        <source>Gray Street Map</source>
        <translation>Grå gatukarta</translation>
    </message>
    <message>
        <source>Color-reduced map view in daylight mode</source>
        <translation>Färgreducerad kartvy i dagsljusläge</translation>
    </message>
    <message>
        <source>Mobile Street Map</source>
        <translation>Gatukarta (mobil)</translation>
    </message>
    <message>
        <source>Mobile normal map view in daylight mode</source>
        <translation>Normal kartvy i dagsljusläge (mobil)</translation>
    </message>
    <message>
        <source>Mobile Terrain Map</source>
        <translation>Terrängkarta (mobil)</translation>
    </message>
    <message>
        <source>Mobile terrain map view in daylight mode</source>
        <translation>Terrängkartvy i dagsljusläge (mobil)</translation>
    </message>
    <message>
        <source>Mobile Hybrid Map</source>
        <translation>Hybridkarta (mobil)</translation>
    </message>
    <message>
        <source>Mobile satellite map view with streets in daylight mode</source>
        <translation>Satellitkartvy med gator i dagsljusläge (mobil)</translation>
    </message>
    <message>
        <source>Mobile Transit Map</source>
        <translation>Pendlarkarta (mobil)</translation>
    </message>
    <message>
        <source>Mobile color-reduced map view with public transport scheme in daylight mode</source>
        <translation>Färgreducerad kartvy med kollektivtrafik i dagsljusläge (mobil)</translation>
    </message>
    <message>
        <source>Mobile Gray Street Map</source>
        <translation>Grå gatukarta (mobil)</translation>
    </message>
    <message>
        <source>Mobile color-reduced map view in daylight mode</source>
        <translation>Färgreducerad kartvy i dagsljusläge (mobil)</translation>
    </message>
    <message>
        <source>Custom Street Map</source>
        <translation>Anpassad gatukarta</translation>
    </message>
    <message>
        <source>Night Street Map</source>
        <translation>Nattgatukarta</translation>
    </message>
    <message>
        <source>Normal map view in night mode</source>
        <translation>Normal kartvy i nattläge</translation>
    </message>
    <message>
        <source>Mobile Night Street Map</source>
        <translation>Nattgatukarta (mobil)</translation>
    </message>
    <message>
        <source>Mobile normal map view in night mode</source>
        <translation>Normal kartvy i nattläge (mobil)</translation>
    </message>
    <message>
        <source>Gray Night Street Map</source>
        <translation>Grå nattgatukarta</translation>
    </message>
    <message>
        <source>Color-reduced map view in night mode (especially used for background maps)</source>
        <translation>Färgreducerad kartvy i nattläge (används specifikt för bakgrundskartor)</translation>
    </message>
    <message>
        <source>Mobile Gray Night Street Map</source>
        <translation>Grå nattgatukarta (mobil)</translation>
    </message>
    <message>
        <source>Mobile color-reduced map view in night mode (especially used for background maps)</source>
        <translation>Färgreducerad kartvy i nattläge (används specifikt för bakgrundskartor)</translation>
    </message>
    <message>
        <source>Pedestrian Street Map</source>
        <translation>Gatukarta för fotgängare</translation>
    </message>
    <message>
        <source>Pedestrian map view in daylight mode</source>
        <translation>Kartvy för fotgängare i dagsljusläge</translation>
    </message>
    <message>
        <source>Mobile Pedestrian Street Map</source>
        <translation>Gatukarta för fotgängare (mobil)</translation>
    </message>
    <message>
        <source>Mobile pedestrian map view in daylight mode for mobile usage</source>
        <translation>Kartvy för fotgängare i dagsljusläge för mobil användning</translation>
    </message>
    <message>
        <source>Pedestrian Night Street Map</source>
        <translation>Nattgatukarta för fotgängare</translation>
    </message>
    <message>
        <source>Pedestrian map view in night mode</source>
        <translation>Kartvy för fotgängare i nattläge</translation>
    </message>
    <message>
        <source>Mobile Pedestrian Night Street Map</source>
        <translation>Nattgatukarta för fotgängare (mobil)</translation>
    </message>
    <message>
        <source>Mobile pedestrian map view in night mode for mobile usage</source>
        <translation>Kartvy för fotgängare i nattläge för mobil användning (mobil)</translation>
    </message>
    <message>
        <source>Car Navigation Map</source>
        <translation>Bilnavigeringskarta</translation>
    </message>
    <message>
        <source>Normal map view in daylight mode for car navigation</source>
        <translation>Normal kartvy i dagsljusläge för bilnavigering</translation>
    </message>
</context>
<context>
    <name>QGeoTileFetcherNokia</name>
    <message>
        <source>Mapping manager no longer exists</source>
        <translation>Mappningshanterare finns inte längre</translation>
    </message>
</context>
<context>
    <name>QGeoRouteParserOsrmV4</name>
    <message>
        <source>Go straight.</source>
        <translation>Gå rakt fram.</translation>
    </message>
    <message>
        <source>Go straight onto %1.</source>
        <translation>Gå rakt fram in på %1.</translation>
    </message>
    <message>
        <source>Turn slightly right.</source>
        <translation>Sväng svagt till höger.</translation>
    </message>
    <message>
        <source>Turn slightly right onto %1.</source>
        <translation>Sväng svagt till höger in på %1.</translation>
    </message>
    <message>
        <source>Turn right.</source>
        <translation>Sväng höger.</translation>
    </message>
    <message>
        <source>Turn right onto %1.</source>
        <translation>Sväng höger in på %1.</translation>
    </message>
    <message>
        <source>Make a sharp right.</source>
        <translation>Gör en skarp högersväng.</translation>
    </message>
    <message>
        <source>Make a sharp right onto %1.</source>
        <translation>Gör en skarp högersväng in på %1.</translation>
    </message>
    <message>
        <source>When it is safe to do so, perform a U-turn.</source>
        <translation>När det är säkert att göra en, gör en u-sväng.</translation>
    </message>
    <message>
        <source>Make a sharp left.</source>
        <translation>Gör en skarp vänstersväng.</translation>
    </message>
    <message>
        <source>Make a sharp left onto %1.</source>
        <translation>Gör en skarp vänstersväng in på %1.</translation>
    </message>
    <message>
        <source>Turn left.</source>
        <translation>Sväng vänster.</translation>
    </message>
    <message>
        <source>Turn left onto %1.</source>
        <translation>Sväng vänster in på %1.</translation>
    </message>
    <message>
        <source>Turn slightly left.</source>
        <translation>Sväng svagt till vänster.</translation>
    </message>
    <message>
        <source>Turn slightly left onto %1.</source>
        <translation>Sväng svagt till vänster in på %1.</translation>
    </message>
    <message>
        <source>Reached waypoint.</source>
        <translation>Du har nått vägpunkten.</translation>
    </message>
    <message>
        <source>Head on.</source>
        <translation>Rakt fram.</translation>
    </message>
    <message>
        <source>Head onto %1.</source>
        <translation>Rakt fram in på %1.</translation>
    </message>
    <message>
        <source>Enter the roundabout.</source>
        <translation>In i rondellen.</translation>
    </message>
    <message>
        <source>At the roundabout take the first exit.</source>
        <translation>Vid rondellen, ta den första avfarten.</translation>
    </message>
    <message>
        <source>At the roundabout take the first exit onto %1.</source>
        <translation>Vid rondellen, ta den första avfarten in på %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the second exit.</source>
        <translation>Vid rondellen, ta den andra avfarten.</translation>
    </message>
    <message>
        <source>At the roundabout take the second exit onto %1.</source>
        <translation>Vid rondellen, ta den andra avfarten in på %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the third exit.</source>
        <translation>Vid rondellen, ta den tredje avfarten.</translation>
    </message>
    <message>
        <source>At the roundabout take the third exit onto %1.</source>
        <translation>Vid rondellen, ta den tredje avfarten in på %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the fourth exit.</source>
        <translation>Vid rondellen, ta den fjärde avfarten.</translation>
    </message>
    <message>
        <source>At the roundabout take the fourth exit onto %1.</source>
        <translation>Vid rondellen, ta den fjärde avfarten in på %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the fifth exit.</source>
        <translation>Vid rondellen, ta den femte avfarten.</translation>
    </message>
    <message>
        <source>At the roundabout take the fifth exit onto %1.</source>
        <translation>Vid rondellen, ta den femte avfarten in på %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the sixth exit.</source>
        <translation>Vid rondellen, ta den sjätte avfarten.</translation>
    </message>
    <message>
        <source>At the roundabout take the sixth exit onto %1.</source>
        <translation>Vid rondellen, ta den sjätte avfarten in på %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the seventh exit.</source>
        <translation>Vid rondellen, ta den sjunde avfarten.</translation>
    </message>
    <message>
        <source>At the roundabout take the seventh exit onto %1.</source>
        <translation>Vid rondellen, ta den sjunde avfarten in på %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the eighth exit.</source>
        <translation>Vid rondellen, ta den åttonde avfarten.</translation>
    </message>
    <message>
        <source>At the roundabout take the eighth exit onto %1.</source>
        <translation>Vid rondellen, ta den åttonde avfarten in på %1.</translation>
    </message>
    <message>
        <source>At the roundabout take the ninth exit.</source>
        <translation>Vid rondellen, ta den nionde avfarten.</translation>
    </message>
    <message>
        <source>At the roundabout take the ninth exit onto %1.</source>
        <translation>Vid rondellen, ta den nionde avfarten in på %1.</translation>
    </message>
    <message>
        <source>Leave the roundabout.</source>
        <translation>Lämna rondellen.</translation>
    </message>
    <message>
        <source>Leave the roundabout onto %1.</source>
        <translation>Lämna rondellen in på %1.</translation>
    </message>
    <message>
        <source>Stay on the roundabout.</source>
        <translation>Håll dig i rondellen.</translation>
    </message>
    <message>
        <source>Start at the end of the street.</source>
        <translation>Börja i slutet av gatan.</translation>
    </message>
    <message>
        <source>Start at the end of %1.</source>
        <translation>Börja i slutet av %1.</translation>
    </message>
    <message>
        <source>You have reached your destination.</source>
        <translation>Du har nått ditt mål.</translation>
    </message>
    <message>
        <source>Don&apos;t know what to say for &apos;%1&apos;</source>
        <translation>Vet inte vad som ska sägas för &quot;%1&quot;</translation>
    </message>
</context>
<context>
    <name>QGeoTiledMappingManagerEngineOsm</name>
    <message>
        <source>Street Map</source>
        <translation>Gatukarta</translation>
    </message>
    <message>
        <source>Street map view in daylight mode</source>
        <translation>Gatukartsvy i dagsljusläge</translation>
    </message>
    <message>
        <source>Satellite Map</source>
        <translation>Satellitkarta</translation>
    </message>
    <message>
        <source>Satellite map view in daylight mode</source>
        <translation>Satellitkartvy i dagsljusläge</translation>
    </message>
    <message>
        <source>Cycle Map</source>
        <translation>Cykelkarta</translation>
    </message>
    <message>
        <source>Cycle map view in daylight mode</source>
        <translation>Cyklingskartvy i dagsljusläge</translation>
    </message>
    <message>
        <source>Transit Map</source>
        <translation>Pendlarkarta</translation>
    </message>
    <message>
        <source>Public transit map view in daylight mode</source>
        <translation>Pendlarkartvy i dagsljusläge</translation>
    </message>
    <message>
        <source>Night Transit Map</source>
        <translation>Nattpendlingskarta</translation>
    </message>
    <message>
        <source>Public transit map view in night mode</source>
        <translation>Pendlarkartvy i nattläge</translation>
    </message>
    <message>
        <source>Terrain Map</source>
        <translation>Terrängkarta</translation>
    </message>
    <message>
        <source>Terrain map view</source>
        <translation>Terrängkartvy</translation>
    </message>
    <message>
        <source>Hiking Map</source>
        <translation>Fotgängarkarta</translation>
    </message>
    <message>
        <source>Hiking map view</source>
        <translation>Fotgängarkartvy</translation>
    </message>
    <message>
        <source>Custom URL Map</source>
        <translation>Anpassad URL-karta</translation>
    </message>
    <message>
        <source>Custom url map view set via urlprefix parameter</source>
        <translation>Anpassad url-kartvy inställd via urlprefix-parametern</translation>
    </message>
</context>
<context>
    <name>QPlaceManagerEngineOsm</name>
    <message>
        <source>Aeroway</source>
        <translation>Flygplats</translation>
    </message>
    <message>
        <source>Amenity</source>
        <translation>Bekvämligheter</translation>
    </message>
    <message>
        <source>Building</source>
        <translation>Byggnad</translation>
    </message>
    <message>
        <source>Highway</source>
        <translation>Motorväg</translation>
    </message>
    <message>
        <source>Historic</source>
        <translation>Historisk plats</translation>
    </message>
    <message>
        <source>Land use</source>
        <translation>Landanvändning</translation>
    </message>
    <message>
        <source>Leisure</source>
        <translation>Nöje</translation>
    </message>
    <message>
        <source>Man made</source>
        <translation>Konstgjord</translation>
    </message>
    <message>
        <source>Natural</source>
        <translation>Naturlig</translation>
    </message>
    <message>
        <source>Place</source>
        <translation>Plats</translation>
    </message>
    <message>
        <source>Railway</source>
        <translation>Järnväg</translation>
    </message>
    <message>
        <source>Shop</source>
        <translation>Affär</translation>
    </message>
    <message>
        <source>Tourism</source>
        <translation>Turism</translation>
    </message>
    <message>
        <source>Waterway</source>
        <translation>Vattenväg</translation>
    </message>
    <message>
        <source>Network request error</source>
        <translation>Fel vid nätverksbegäran</translation>
    </message>
</context>
<context>
    <name>QPlaceSearchReplyOsm</name>
    <message>
        <source>Response parse error</source>
        <translation>Tolkningsfel av svaret</translation>
    </message>
</context>
</TS>
